#!/bin/bash
# http://www.vcdimager.org/
# http://www.gnu.org/software/vcdimager/
PKG_URL=ftp://ftp.gnu.org/gnu/vcdimager/
#
# Consider recompiling libcdio (CD input & control library)
# with --enable-vcd-info # include Video CD Info from libvcd
#
# script: til <rob DOT til DOT freedman AT googlemail DOT com>
#
REPO=http://zenwalk.pinguix.com/user-accounts/tilderb/extra/ap/vcdimager
set -e -u -x

# vcdimager
version=0.7.23
#
build=${build:-64.1}
arch=${arch:-i486}
tune=${tune:-i686}

pkgname=vcdimager-$version
package=$pkgname-$arch-$build

PKG_DEP="libcdio,libxml2,popt,zlib"
PKG_SRC="$PKG_URL/$pkgname.tar.gz
$REPO/build-vcdimager.sh"

# build directory
CWD=`pwd`
TMP=${TMP:-$CWD}
SRC=$TMP/$pkgname
PKG=$TMP/$package

# prepare build directory
[ -d $SRC ] && rm -fr $SRC
[ -d $PKG ] && rm -fr $PKG

mkdir -p $SRC $PKG/{install,usr/{src,doc}/$pkgname}
#
tar xzf $CWD/$pkgname.tar.gz --strip-components=1 -C $SRC
cd $SRC
#./configure --help >$CWD/configure-help

CFLAGS="-O2 -march=$arch -mtune=$tune" \
CXXFLAGS="-O2 -march=$arch -mtune=$tune" \
 ./configure --prefix=/usr --disable-static

make || exit 1
make DESTDIR=$PKG install

# helperline
find . -printf "%y %m %u:%g %p %l\n" |sort >$CWD/make.installed

# docs
cp -a COPYING ChangeLog README AUTHORS TODO THANKS NEWS BUGS FAQ HACKING \
    $PKG/usr/doc/$pkgname

cd $PKG
gzip -9 usr/doc/$pkgname/ChangeLog

# strip symbols
find usr/ |xargs -r file |grep "executable\|shared object" |grep ELF |\
	cut -f 1 -d : | xargs -r strip --strip-unneeded

#find . |xargs file |grep "current ar archive" |\
#	cut -f 1 -d : | xargs -r strip -g
	
# zip man/info pages
rm usr/info/dir
find usr/man/man1/ usr/info -type f | xargs gzip -9

# copy build script
cp $CWD/build-vcdimager.sh usr/src/$pkgname

# copy slack description
#    |-----handy-ruler------------------------------------------------------|
cat <<"EOF" > install/slack-desc
vcdimager: vcdimager (vcd/svcd mastering suite)
vcdimager:
vcdimager: vcdimager is a full-featured mastering suite for authoring,
vcdimager: disassembling and analyzing Video CD's and Super Video CD's.
vcdimager:
EOF

cat <<EOF > install/doinst.sh
# update info dir
if [ -x usr/bin/install-info ] ; then
	for i in $(ls -x usr/info); do
		usr/bin/install-info usr/info/\$i usr/info/dir
	done
fi
EOF

fakeroot /sbin/makepkg -l y -c n $CWD/$package.txz
cd $CWD
echo $PKG_DEP >$package.dep
#depfinder $PKG >$package.dep
echo "$PKG_SRC" >$package.src
md5sum $package.txz >$package.md5

